#!/bin/sh
export PATH='/usr/obj/ports/hs-dbus-0.10.13/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: dbus
version: 0.10.13
id: dbus-0.10.13-d9ca5f7741f584426b6973f02e4affe5
key: dbus_86vmMsycG5aDChJhqAXTgY
license: GPL-3
maintainer: Andrey Sverdlichenko <blaze@ruddy.ru>, John Millikin <john@john-millikin.com>
stability: experimental
homepage: https://github.com/rblaze/haskell-dbus#readme
synopsis: A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.
    .
    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.
    .
    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.
    .
    Example: connect to the session bus, and get a list of active names.
    .
    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;
    .
    import Data.List (sort)
    import DBus
    import DBus.Client
    .
    main = do
    &#x20;   client <- connectSession
    &#x20;   //
    &#x20;   \-- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;   //
    &#x20;   \-- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   \-- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;   //
    &#x20;   \-- Print each name on a line, sorted so reserved names are below
    &#x20;   \-- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @
    .
    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver
category: Network, Desktop
author: John Millikin <john@john-millikin.com>
exposed: True
exposed-modules:
    DBus DBus.Client DBus.Introspection DBus.Socket DBus.Transport
    DBus.Internal.Address DBus.Internal.Message DBus.Internal.Types
    DBus.Internal.Wire
trusted: False
import-dirs: /usr/local/lib/ghc/dbus-0.10.13
library-dirs: /usr/local/lib/ghc/dbus-0.10.13
data-dir: /usr/local/share/hs-dbus-0.10.13
hs-libraries: HSdbus-0.10.13-86vmMsycG5aDChJhqAXTgY
depends:
    base-4.8.2.0-3d77ba9c3882e564c6ef1b6e7015bbb1
    bytestring-0.10.6.0-e64194d00131ba3386784c6b067aaaac
    cereal-0.4.1.0-7d381ec81cd00a9ccdaa13b77e9ebf00
    containers-0.5.6.2-72662c7d6dea4fa8c95128efb85ebc60
    libxml-sax-0.7.5-816104299289914989e2d885e0bfe928
    network-2.6.2.1-3b665743d23d24bea9ea15fe12214a85
    parsec-3.1.9-0bc62b5601d05cd60af5b5aa86497840
    random-1.1-29ff1dff757b7db4e436b4cdcc22a979
    text-1.2.1.3-b81318aa9c5f332f4a693000ebc8a335
    transformers-0.4.2.0-a5bbd954d1c2451a9da96a3615054cc0
    unix-2.7.1.0-af352a62ad999f21f39086c37a903c3b
    vector-0.11.0.0-038317210aedffb94db1b450a91d7de1
    xml-types-0.3.6-8dc9287ff5f359f6503e5d06849b8058
haddock-interfaces: /usr/local/share/doc/hs-dbus-0.10.13/html/dbus.haddock
haddock-html: /usr/local/share/doc/hs-dbus-0.10.13/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
